@@ -2,7 +2,7 @@
 #
 # Copyright (C) 2007-2009 Luca Falavigna
 #
-# Author: Luca Falavigna <dktrkranz@ubuntu.com>
+# Author: Luca Falavigna <dktrkranz@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@ import os
 import sys
 import threading
 from re import findall
-from sha import new
 from string import lower
 from Debomatic import gpg
 from Debomatic import locks
@@ -85,6 +84,10 @@ def parse_distribution_options(packagedir, configdir, package):
         sys.exit(-1)
     conf = os.read(fd, os.fstat(fd).st_size)
     os.close(fd)
+    if not len(findall('[^#]?MIRRORSITE="?(.*[^"])"?\n', conf)):
+        print 'Please set DISTRIBUTION in %s' % os.path.join(configdir, options['distribution'])
+        packages.del_package(package)
+        sys.exit(-1)
     try:
         options['mirror'] = findall('[^#]?MIRRORSITE="?(.*[^"])"?\n', conf)[0]
     except:
@@ -111,8 +114,8 @@ def build_package(directory, configfile, distdir, package, distopts):
         packages.del_package(package)
         sys.exit(-1)
     dscfile = None
-    if not os.path.exists(os.path.join(distdir, 'result')):
-        os.mkdir(os.path.join(distdir, 'result'))
+    if not os.path.exists(os.path.join(distdir, 'pool')):
+        os.mkdir(os.path.join(distdir, 'pool'))
     for pkgfile in packagequeue[package]:
             if not dscfile:
                 dscfile = findall('(.*\.dsc$)', pkgfile)
@@ -120,15 +123,14 @@ def build_package(directory, configfile, distdir, package, distopts):
         packageversion = findall('.*/(.*).dsc$', dscfile[0])[0]
     except:
         packageversion = None
-    if not os.path.exists(os.path.join(distdir, 'result', packageversion)):
-        os.mkdir(os.path.join(distdir, 'result', packageversion))
+    if not os.path.exists(os.path.join(distdir, 'pool', packageversion)):
+        os.mkdir(os.path.join(distdir, 'pool', packageversion))
     mod_sys.execute_hook('pre_build', { 'directory': distdir, 'package': packageversion, \
               'cfg': configfile, 'distribution': distopts['distribution'], 'dsc': dscfile[0]})
     os.system('pbuilder build --basetgz %(directory)s/%(distribution)s \
-              --distribution %(distribution)s --override-config --configfile %(cfg)s \
-              --logfile %(directory)s/result/%(package)s/%(package)s.buildlog \
-              --buildplace %(directory)s/build --buildresult %(directory)s/result/%(package)s \
-              --aptcache %(directory)s/aptcache %(dsc)s' % { 'directory': distdir, 'package': packageversion, \
+              --override-config --configfile %(cfg)s --logfile %(directory)s/pool/%(package)s/%(package)s.buildlog \
+              --buildplace %(directory)s/build --buildresult %(directory)s/pool/%(package)s \
+              --aptcache %(directory)s/aptcache %(dsc)s >/dev/null 2>&1' % { 'directory': distdir, 'package': packageversion, \
               'cfg': configfile, 'distribution': distopts['distribution'], 'dsc': dscfile[0]})
     mod_sys.execute_hook('post_build', { 'directory': distdir, 'package': packageversion, \
               'cfg': configfile, 'distribution': distopts['distribution'], 'dsc': dscfile[0]})
