@@ -2,7 +2,7 @@
 #
 # Copyright (C) 2007-2009 Luca Falavigna
 #
-# Author: Luca Falavigna <dktrkranz@ubuntu.com>
+# Author: Luca Falavigna <dktrkranz@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,11 +20,13 @@
 import os
 import sys
 import threading
+from fcntl import lockf, LOCK_EX, LOCK_NB
 from getopt import getopt, GetoptError
 from time import sleep
 from Debomatic import build
 from Debomatic import Options
 from Debomatic import modules
+from Debomatic import running
 
 def main():
     conffile = None
@@ -70,6 +72,12 @@ def main():
         os.dup2(fout.fileno(), sys.stdout.fileno())
         os.dup2(ferr.fileno(), sys.stderr.fileno())
 
+    fd = os.open('/var/run/debomatic.lock', os.O_WRONLY | os.O_CREAT | os.O_TRUNC)
+    try:
+        lockf(fd, LOCK_EX | LOCK_NB)
+    except IOError:
+        print 'Another instance is running. Aborting.'
+        sys.exit(-1)
     mod_sys = modules.Module()
     mod_sys.execute_hook("on_start", {})
     launcher()
@@ -90,37 +98,44 @@ def parse_default_options(conffile):
 
 try:
     import os
+    import pyinotify
     from re import findall
-    from pyinotify import WatchManager, Notifier, EventsCodes, ProcessEvent
 
-    class PE(ProcessEvent):
+    class PE(pyinotify.ProcessEvent):
         def process_IN_CLOSE_WRITE(self, event):
             if findall('source.changes$', event.name):
                 threading.Thread(None, build.build_process).start()
 
     def launcher_inotify():
         if Options.getint('default', 'inotify'):
-            wm = WatchManager()
-            notifier = Notifier(wm, PE())
-            wm.add_watch(Options.get('default', 'packagedir'), EventsCodes.IN_CLOSE_WRITE, rec=True)
-            while True:
-                try:
-                    notifier.process_events()
-                    if notifier.check_events():
-                        notifier.read_events()
-                except KeyboardInterrupt:
-                    notifier.stop()
-                    break
+            wm = pyinotify.WatchManager()
+            notifier = pyinotify.Notifier(wm, PE())
+            wm.add_watch(Options.get('default', 'packagedir'), pyinotify.IN_CLOSE_WRITE, rec=True)
+            notifier.loop(callback=exit_routine)
 except:
     def launcher_inotify():
         pass
 
 def launcher_timer():
-    while 1:
+    while exit_routine():
         threading.Thread(None, build.build_process).start()
         sleep(Options.getint('default', 'sleep'))
 
 def launcher():
     threading.Thread(None, launcher_inotify).start()
     threading.Thread(None, launcher_timer).start()
+    try:
+        while exit_routine():
+            pass
+    except KeyboardInterrupt:
+        print '\nWaiting for threads to finish, it could take a while...'
+        exit_routine(exiting=True)
 
+def exit_routine(self=None, exiting=False):
+    global running
+    if exiting:
+        running = False
+        return
+    if not running:
+        sys.exit(0)
+    return running
