@@ -2,7 +2,7 @@
 #
 # Copyright (C) 2007-2009 Luca Falavigna
 #
-# Author: Luca Falavigna <dktrkranz@ubuntu.com>
+# Author: Luca Falavigna <dktrkranz@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 
 import os
 import sys
-from sha import new
+from hashlib import sha256
 from time import strftime
 from urllib import urlopen
 from Debomatic import locks
@@ -62,8 +62,10 @@ def needs_update(directory, mirror, distribution):
     except:
         print 'Unable to fetch %s/dists/%s/Release.gpg' % (mirror, distribution)
         return 'update'
-    remote_sha = new(remote)
-    gpgfile_sha = new(os.read(fd, os.fstat(fd).st_size))
+    remote_sha = sha256()
+    gpgfile_sha = sha256()
+    remote_sha.update(remote)
+    gpgfile_sha.update(os.read(fd, os.fstat(fd).st_size))
     os.close(fd)
     if remote_sha.digest() != gpgfile_sha.digest():
         return 'update'
@@ -76,9 +78,8 @@ def prepare_pbuilder(cmd, directory, configdir, distopts):
     if not os.path.exists(os.path.join(directory, 'logs')):
         os.mkdir(os.path.join(directory, 'logs'))
     if (os.system('pbuilder %(cmd)s --basetgz %(directory)s/%(distribution)s \
-                  --distribution %(distribution)s --override-config \
-                  --configfile %(cfg)s --buildplace %(directory)s/build \
-                  --aptcache "%(directory)s/aptcache" --logfile %(directory)s/logs/%(cmd)s.%(now)s' \
+                  --override-config --configfile %(cfg)s --buildplace %(directory)s/build \
+                  --aptcache "%(directory)s/aptcache" --logfile %(directory)s/logs/%(cmd)s.%(now)s >/dev/null 2>&1' \
                   % {'cmd': cmd, 'directory': directory, 'distribution': distopts['distribution'], \
                   'cfg': os.path.join(configdir, distopts['distribution']), 'now': strftime('%Y%m%d_%H%M')})):
         print 'pbuilder (%s) failed' % cmd
